=== added directory 'docs'
=== added file 'docs/device-api.txt'
--- docs/device-api.txt	1970-01-01 00:00:00 +0000
+++ docs/device-api.txt	2015-12-01 09:02:16 +0000
@@ -0,0 +1,55 @@
+Device hierarchy
+================
+
+Service		org.wds
+Interface	org.wds.Device
+Object path	/dev_*
+
+Methods		void Connect()
+
+			This method will try to connect with the remote
+			display device.
+
+			Possible errors: org.wds.Error.NotReady
+					  org.wds.Error.Failed
+					  org.wds.Error.InProgress
+					  org.wds.Error.AlreadyConnected
+
+		void Disconnect()
+
+			This method will attempt to disconnect a
+			currently connected device.
+
+			It can also be used to cancel a preceding Connect
+			call before a reply to it has been received.
+
+			Possible errors: org.wds.Error.NotConnected
+
+
+Properties		string State
+
+			The current state of the device. Possible values
+			are "idle", "connecting", "connected" and "failure".
+
+			If a device is not currently connected or connecting
+			its state is either "idle" or "failure". It switches
+			to "failure" if a connection attempt failed.
+
+			If a device is being connected it will switch to
+			"connecting" and to "connected" or "failure" as
+			next state. If the connection attempt was successful
+			it will switch to "connected" and otherwise to
+			"failure".
+
+			If a device gets disconnected it will switch back
+			to "idle".
+
+		string Name
+
+			Name of the remote device
+
+		array{string} Capabilities
+
+			List of capabilities the remote device has. Possible
+			values are "sink" and "source".
+

=== added file 'docs/manager-api.txt'
--- docs/manager-api.txt	1970-01-01 00:00:00 +0000
+++ docs/manager-api.txt	2015-12-01 09:02:16 +0000
@@ -0,0 +1,32 @@
+Manager hierarchy
+=================
+
+Service		org.wds
+Interface	org.wds.Manager
+Object path	/
+
+Methods		void Scan()
+
+			Trigger a scan for available display devices. The
+			method call will return when a scan has been
+			finished and results are available. So setting
+			a longer D-Bus timeout might be a really good
+			idea.
+
+Properties	string State [readonly]
+
+			The global connection state. Possible values are
+			"offline", "idle" and "connected".
+
+			If the underlaying transport technology is turned
+			off the state will be "offline" to reflect we
+			can't do any operation. All devices will be
+			disconnected in this state.
+
+			When the underlaying transport technology is
+			turned on and no device is connected the manager
+			will be in "idle" mode. This marks the manager
+			as being ready to connect with a remote device.
+
+			If atleast one device is connected the state
+			will be "connected".

=== added file 'docs/overview.txt'
--- docs/overview.txt	1970-01-01 00:00:00 +0000
+++ docs/overview.txt	2015-12-01 09:02:16 +0000
@@ -0,0 +1,35 @@
+DBus API Overview
+=================
+
+The service implements a top level manager object at / which implements
+the following interfaces:
+
+ - org.wds.Manager
+ - org.freedesktop.DBus.ObjectManager
+ - org.freedesktop.DBus.Properties
+
+Through the ObjectManager interface all device objects are managed.
+
+The device objects itself will sit on a path formed by the following
+format:
+
+    /dev_*
+
+Where the suffix will be some kind of identifier for the device. The
+only valid way to find out which device objects are available is
+through the ObjectManager interface.
+
+Each device object will implement the following interfaces:
+
+ - org.wds.Device
+ - org.freedesktop.DBus.Properties
+
+API Versioning
+--------------
+
+After the API is considered stable we will gurantee it will not break.
+If breaking changes are introduced this will be reflected in the major
+version of the service being increased and the interface being appened
+with a increasing number. For example if the org.wds.Device interface
+is changed in a breaking way a new interface will be defined with the
+name org.wds.Device1 to reflect the API breakage.

